@@ -1,4 +1,4 @@
-# Copyright (C) 2003, 2004  Free Software Foundation, Inc.
+# Copyright (C) 2003, 2004, 2006  Free Software Foundation, Inc.
 
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -11,9 +11,7 @@
 # GNU General Public License for more details.
 
 # You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-# 02110-1301, USA.
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 package Automake::VarDef;
 use strict;
@@ -71,7 +69,7 @@ Automake::VarDef - a class for variable definitions
 
 =head1 DESCRIPTION
 
-This class gather data related to one Makefile-variable definition.
+This class gathers data related to one Makefile-variable definition.
 
 =head2 Constants
 
@@ -100,7 +98,7 @@ C<VAR_SORTED> variables should be sorted and then handled as
 C<VAR_PRETTY> variables.
 
 C<VAR_SILENT> variables can also be overridden silently (unlike the
-other kinds of variables whose overridding may sometimes produce
+other kinds of variables whose overriding may sometimes produce
 warnings).
 
 =cut
@@ -130,7 +128,7 @@ C<$comment> is any comment preceding the definition.  (Because
 Automake reorders variable definitions in the output, it also tries to
 carry comments around.)
 
-C<$location> is the place where the definition occured, it should be
+C<$location> is the place where the definition occurred, it should be
 an instance of L<Automake::Location>.
 
 C<$type> should be C<''> for definitions made with C<=>, and C<':'>
@@ -167,7 +165,7 @@ sub new ($$$$$$$$)
 
 =item C<$def-E<gt>append ($value, $comment)>
 
-Append C<$value> and <$comment> to the exisiting value and comment of
+Append C<$value> and <$comment> to the existing value and comment of
 C<$def>.  This is normally called on C<+=> definitions.
 
 =cut
@@ -187,17 +185,8 @@ sub append ($$$)
   # Furthermore keeping `#' would not be portable if the variable is
   # output on multiple lines.
   $val =~ s/ ?#.*//;
-
-  if (chomp $val)
-    {
-      # Insert a backslash before a trailing newline.
-      $val .= "\\\n";
-    }
-  elsif ($val)
-    {
-      # Insert a separator.
-      $val .= ' ';
-    }
+  # Insert a separator, if required.
+  $val .= ' ' if $val;
   $self->{'value'} = $val . $value;
   # Turn ASIS appended variables into PRETTY variables.  This is to
   # cope with `make' implementation that cannot read very long lines.
